==> apache-camel-3.4.2-src.zip: apache-camel-3.4.2/components/camel-wordpress/src/main/java/org/apache/camel/component/wordpress/proxy/WordpressOperationType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.wordpress.proxy;

import org.apache.camel.component.wordpress.api.model.PostSearchCriteria;
import org.apache.camel.component.wordpress.api.model.SearchCriteria;
import org.apache.camel.component.wordpress.api.model.UserSearchCriteria;

/**
 * List of supported operations.
 */
public enum WordpressOperationType {

    post(PostSearchCriteria.class), user(UserSearchCriteria.class);

    private final Class<? extends SearchCriteria> criteriaType;

    WordpressOperationType(Class<? extends SearchCriteria> criteriaType) {
        this.criteriaType = criteriaType;
    }

    public Class<? extends SearchCriteria> getCriteriaType() {
        return criteriaType;
    }

}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/components/camel-wordpress/src/main/java/org/apache/camel/component/wordpress/proxy/WordpressOperationType.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.wordpress.proxy;

import org.apache.camel.component.wordpress.api.model.PostSearchCriteria;
import org.apache.camel.component.wordpress.api.model.SearchCriteria;
import org.apache.camel.component.wordpress.api.model.UserSearchCriteria;

/**
 * List of supported operations.
 */
public enum WordpressOperationType {

    post(PostSearchCriteria.class),
    user(UserSearchCriteria.class);

    private final Class<? extends SearchCriteria> criteriaType;

    WordpressOperationType(Class<? extends SearchCriteria> criteriaType) {
        this.criteriaType = criteriaType;
    }

    public Class<? extends SearchCriteria> getCriteriaType() {
        return criteriaType;
    }

}
